<?php

namespace Litepie\Team\Actions;

use Illuminate\Support\Carbon;
use Illuminate\Support\Str;
use Litepie\Actions\Concerns\AsAction;
use Litepie\Actions\Traits\LogsActions;
use Litepie\Notification\Traits\SendNotification;
use Litepie\Team\Models\Team;


class TeamAction
{
    use AsAction;
    use LogsActions;
    use SendNotification;

    private $model;

    public function handle(string $action, Team $team, array $request = [])
    {
        $this->model = $team;

        $function = Str::camel($action);
        event('litepie.team.team.action.' . $action . 'ing', [$team]);
        $data =  $this->$function($team, $request);
        event('litepie.team.team.action.' . $action . 'ed', [$team]);

        $this->logsAction();
        $this->notify();
        return $data;
    }


    public function store(Team $team, array $request)
    {
        $attributes = $request;
        $attributes['user_id'] = user_id();
        $attributes['user_type'] = user_type();
        $team = $team->create($attributes);
        return $team;
    }

    public function update(Team $team, array $request)
    {
        $attributes = $request;
        $team->update($attributes);
        return $team;
    }

    public function destroy(Team $team, array $request)
    {
        $team->delete();
        return $team;
    }

    public function copy(Team $team, array $request)
    {
        $count = $request['count'] ?: 1;

        if ($count == 1) {
            $team = $team->replicate();
            $team->created_at = Carbon::now();
            $team->save();
            return $team;
        }

        for ($i = 1; $i <= $count; $i++) {
            $new = $team->replicate();
            $new->created_at = Carbon::now();
            $new->save();
        }

        return $team;
    }


}
