<?php

namespace Litepie\Team\Actions;

use Illuminate\Support\Carbon;
use Illuminate\Support\Str;
use Litepie\Actions\Concerns\AsAction;
use Litepie\Actions\Traits\LogsActions;
use Litepie\Notification\Traits\SendNotification;
use Litepie\Team\Models\Type;


class TypeAction
{
    use AsAction;
    use LogsActions;
    use SendNotification;

    private $model;

    public function handle(string $action, Type $type, array $request = [])
    {
        $this->model = $type;

        $function = Str::camel($action);
        event('litepie.team.type.action.' . $action . 'ing', [$type]);
        $data =  $this->$function($type, $request);
        event('litepie.team.type.action.' . $action . 'ed', [$type]);

        $this->logsAction();
        $this->notify();
        return $data;
    }


    public function store(Type $type, array $request)
    {
        $attributes = $request;
        $attributes['user_id'] = user_id();
        $attributes['user_type'] = user_type();
        $type = $type->create($attributes);
        return $type;
    }

    public function update(Type $type, array $request)
    {
        $attributes = $request;
        $type->update($attributes);
        return $type;
    }

    public function destroy(Type $type, array $request)
    {
        $type->delete();
        return $type;
    }

    public function copy(Type $type, array $request)
    {
        $count = $request['count'] ?: 1;

        if ($count == 1) {
            $type = $type->replicate();
            $type->created_at = Carbon::now();
            $type->save();
            return $type;
        }

        for ($i = 1; $i <= $count; $i++) {
            $new = $type->replicate();
            $new->created_at = Carbon::now();
            $new->save();
        }

        return $type;
    }


}
