<?php

namespace Litepie\Team\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Litepie\Team\Models\Type;

class TypePolicy
{


    /**
     * Determine if the given user can view the type.
     *
     * @param UserPolicyInterface $authUser
     * @param Type $type
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Type $type)
    {
        if ($authUser->canDo('team.type.view') && $authUser->isAdmin()) {
            return true;
        }

        return $type->user_id == user_id() && $type->user_type == user_type();
    }

    /**
     * Determine if the given user can create a type.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('team.type.create');
    }

    /**
     * Determine if the given user can update the given type.
     *
     * @param UserPolicyInterface $authUser
     * @param Type $type
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Type $type)
    {
        if ($authUser->canDo('team.type.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $type->user_id == user_id() && $type->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given type.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Type $type)
    {
        return $type->user_id == user_id() && $type->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given type.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Type $type)
    {
        if ($authUser->canDo('team.type.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given type.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Type $type)
    {
        if ($authUser->canDo('team.type.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
