<?php

namespace Litepie\Team\Providers;

use Illuminate\Support\ServiceProvider;
use Litepie\Team\Teams;

class TeamServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = true;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'team');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'team');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();

        $this->app->register(\Litepie\Team\Providers\AuthServiceProvider::class);
        $this->app->register(\Litepie\Team\Providers\RouteServiceProvider::class);
    }


    /**
     * Merges user's and team's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'litepie.team'
        );
        
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/team.php', 'litepie.team.team'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/type.php', 'litepie.team.type'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/role.php', 'litepie.team.role'
        );
    }


    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litepie.team'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/' => config_path('litepie/team')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/team')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/team')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
